# coding: utf-8

"""
    Vericred API

    Vericred's API allows you to search for Health Plans that a specific doctor
accepts.

## Getting Started

Visit our [Developer Portal](https://vericred.3scale.net) to
create an account.

Once you have created an account, you can create one Application for
Production and another for our Sandbox (select the appropriate Plan when
you create the Application).

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v3`.  Previous versions are `v1` and `v2`.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v2' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their `State`s
we sideload the associated data.  In this example, we would provide an Array of
`State`s and a `state_id` for each provider.  This is done primarily to reduce the
payload size since many of the `Provider`s will share a `State`

```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` query string parameter for the corresponding fields in the JSON
document.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,staes.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/12345?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```



    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class RequestProvidersSearch(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, accepts_insurance=None, hios_ids=None, min_score=None, page=None, per_page=None, radius=None, search_term=None, zip_code=None, type=None):
        """
        RequestProvidersSearch - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'accepts_insurance': 'bool',
            'hios_ids': 'list[str]',
            'min_score': 'float',
            'page': 'int',
            'per_page': 'int',
            'radius': 'int',
            'search_term': 'str',
            'zip_code': 'str',
            'type': 'str'
        }

        self.attribute_map = {
            'accepts_insurance': 'accepts_insurance',
            'hios_ids': 'hios_ids',
            'min_score': 'min_score',
            'page': 'page',
            'per_page': 'per_page',
            'radius': 'radius',
            'search_term': 'search_term',
            'zip_code': 'zip_code',
            'type': 'type'
        }

        self._accepts_insurance = accepts_insurance
        self._hios_ids = hios_ids
        self._min_score = min_score
        self._page = page
        self._per_page = per_page
        self._radius = radius
        self._search_term = search_term
        self._zip_code = zip_code
        self._type = type

    @property
    def accepts_insurance(self):
        """
        Gets the accepts_insurance of this RequestProvidersSearch.
        Limit results to Providers who accept at least one insurance         plan.  Note that the inverse of this filter is not supported and         any value will evaluate to true

        :return: The accepts_insurance of this RequestProvidersSearch.
        :rtype: bool
        """
        return self._accepts_insurance

    @accepts_insurance.setter
    def accepts_insurance(self, accepts_insurance):
        """
        Sets the accepts_insurance of this RequestProvidersSearch.
        Limit results to Providers who accept at least one insurance         plan.  Note that the inverse of this filter is not supported and         any value will evaluate to true

        :param accepts_insurance: The accepts_insurance of this RequestProvidersSearch.
        :type: bool
        """

        self._accepts_insurance = accepts_insurance

    @property
    def hios_ids(self):
        """
        Gets the hios_ids of this RequestProvidersSearch.
        List of HIOS ids

        :return: The hios_ids of this RequestProvidersSearch.
        :rtype: list[str]
        """
        return self._hios_ids

    @hios_ids.setter
    def hios_ids(self, hios_ids):
        """
        Sets the hios_ids of this RequestProvidersSearch.
        List of HIOS ids

        :param hios_ids: The hios_ids of this RequestProvidersSearch.
        :type: list[str]
        """

        self._hios_ids = hios_ids

    @property
    def min_score(self):
        """
        Gets the min_score of this RequestProvidersSearch.
        Minimum search threshold to be included in the results

        :return: The min_score of this RequestProvidersSearch.
        :rtype: float
        """
        return self._min_score

    @min_score.setter
    def min_score(self, min_score):
        """
        Sets the min_score of this RequestProvidersSearch.
        Minimum search threshold to be included in the results

        :param min_score: The min_score of this RequestProvidersSearch.
        :type: float
        """

        self._min_score = min_score

    @property
    def page(self):
        """
        Gets the page of this RequestProvidersSearch.
        Page number

        :return: The page of this RequestProvidersSearch.
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """
        Sets the page of this RequestProvidersSearch.
        Page number

        :param page: The page of this RequestProvidersSearch.
        :type: int
        """

        self._page = page

    @property
    def per_page(self):
        """
        Gets the per_page of this RequestProvidersSearch.
        Number of records to return per page

        :return: The per_page of this RequestProvidersSearch.
        :rtype: int
        """
        return self._per_page

    @per_page.setter
    def per_page(self, per_page):
        """
        Sets the per_page of this RequestProvidersSearch.
        Number of records to return per page

        :param per_page: The per_page of this RequestProvidersSearch.
        :type: int
        """

        self._per_page = per_page

    @property
    def radius(self):
        """
        Gets the radius of this RequestProvidersSearch.
        Radius (in miles) to use to limit results

        :return: The radius of this RequestProvidersSearch.
        :rtype: int
        """
        return self._radius

    @radius.setter
    def radius(self, radius):
        """
        Sets the radius of this RequestProvidersSearch.
        Radius (in miles) to use to limit results

        :param radius: The radius of this RequestProvidersSearch.
        :type: int
        """

        self._radius = radius

    @property
    def search_term(self):
        """
        Gets the search_term of this RequestProvidersSearch.
        String to search by

        :return: The search_term of this RequestProvidersSearch.
        :rtype: str
        """
        return self._search_term

    @search_term.setter
    def search_term(self, search_term):
        """
        Sets the search_term of this RequestProvidersSearch.
        String to search by

        :param search_term: The search_term of this RequestProvidersSearch.
        :type: str
        """

        self._search_term = search_term

    @property
    def zip_code(self):
        """
        Gets the zip_code of this RequestProvidersSearch.
        Zip Code to search near

        :return: The zip_code of this RequestProvidersSearch.
        :rtype: str
        """
        return self._zip_code

    @zip_code.setter
    def zip_code(self, zip_code):
        """
        Sets the zip_code of this RequestProvidersSearch.
        Zip Code to search near

        :param zip_code: The zip_code of this RequestProvidersSearch.
        :type: str
        """

        self._zip_code = zip_code

    @property
    def type(self):
        """
        Gets the type of this RequestProvidersSearch.
        Either organization or individual

        :return: The type of this RequestProvidersSearch.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this RequestProvidersSearch.
        Either organization or individual

        :param type: The type of this RequestProvidersSearch.
        :type: str
        """

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Vericred API

    Vericred's API allows you to search for Health Plans that a specific doctor
accepts.

## Getting Started

Visit our [Developer Portal](https://vericred.3scale.net) to
create an account.

Once you have created an account, you can create one Application for
Production and another for our Sandbox (select the appropriate Plan when
you create the Application).

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v3`.  Previous versions are `v1` and `v2`.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v2' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their `State`s
we sideload the associated data.  In this example, we would provide an Array of
`State`s and a `state_id` for each provider.  This is done primarily to reduce the
payload size since many of the `Provider`s will share a `State`

```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` query string parameter for the corresponding fields in the JSON
document.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,staes.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/12345?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```



    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class DrugsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_drug_coverages(self, ndc_package_code, audience, state_code, **kwargs):
        """
        Search for DrugCoverages
        Drug Coverages are the specific tier level, quantity limit, prior authorization and step therapy for a given Drug/Plan combination. This endpoint returns all DrugCoverages for a given Drug

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_drug_coverages(ndc_package_code, audience, state_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str ndc_package_code: NDC package code (required)
        :param str audience: Two-character state code (required)
        :param str state_code: Two-character state code (required)
        :return: DrugCoverageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_drug_coverages_with_http_info(ndc_package_code, audience, state_code, **kwargs)
        else:
            (data) = self.get_drug_coverages_with_http_info(ndc_package_code, audience, state_code, **kwargs)
            return data

    def get_drug_coverages_with_http_info(self, ndc_package_code, audience, state_code, **kwargs):
        """
        Search for DrugCoverages
        Drug Coverages are the specific tier level, quantity limit, prior authorization and step therapy for a given Drug/Plan combination. This endpoint returns all DrugCoverages for a given Drug

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_drug_coverages_with_http_info(ndc_package_code, audience, state_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str ndc_package_code: NDC package code (required)
        :param str audience: Two-character state code (required)
        :param str state_code: Two-character state code (required)
        :return: DrugCoverageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ndc_package_code', 'audience', 'state_code']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_drug_coverages" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ndc_package_code' is set
        if ('ndc_package_code' not in params) or (params['ndc_package_code'] is None):
            raise ValueError("Missing the required parameter `ndc_package_code` when calling `get_drug_coverages`")
        # verify the required parameter 'audience' is set
        if ('audience' not in params) or (params['audience'] is None):
            raise ValueError("Missing the required parameter `audience` when calling `get_drug_coverages`")
        # verify the required parameter 'state_code' is set
        if ('state_code' not in params) or (params['state_code'] is None):
            raise ValueError("Missing the required parameter `state_code` when calling `get_drug_coverages`")

        resource_path = '/drug_packages/{ndc_package_code}/coverages'.replace('{format}', 'json')
        path_params = {}
        if 'ndc_package_code' in params:
            path_params['ndc_package_code'] = params['ndc_package_code']

        query_params = {}
        if 'audience' in params:
            query_params['audience'] = params['audience']
        if 'state_code' in params:
            query_params['state_code'] = params['state_code']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept([])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Vericred-Api-Key']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DrugCoverageResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def list_drugs(self, search_term, **kwargs):
        """
        Drug Search
        Search for drugs by proprietary name

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_drugs(search_term, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str search_term: Full or partial proprietary name of drug (required)
        :return: DrugSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_drugs_with_http_info(search_term, **kwargs)
        else:
            (data) = self.list_drugs_with_http_info(search_term, **kwargs)
            return data

    def list_drugs_with_http_info(self, search_term, **kwargs):
        """
        Drug Search
        Search for drugs by proprietary name

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_drugs_with_http_info(search_term, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str search_term: Full or partial proprietary name of drug (required)
        :return: DrugSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['search_term']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_drugs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'search_term' is set
        if ('search_term' not in params) or (params['search_term'] is None):
            raise ValueError("Missing the required parameter `search_term` when calling `list_drugs`")

        resource_path = '/drugs'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'search_term' in params:
            query_params['search_term'] = params['search_term']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Vericred-Api-Key']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DrugSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))



# coding: utf-8

"""
    Vericred API

    Vericred's API allows you to search for Health Plans that a specific doctor
accepts.

## Getting Started

Visit our [Developer Portal](https://vericred.3scale.net) to
create an account.

Once you have created an account, you can create one Application for
Production and another for our Sandbox (select the appropriate Plan when
you create the Application).

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v3`.  Previous versions are `v1` and `v2`.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v2' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their `State`s
we sideload the associated data.  In this example, we would provide an Array of
`State`s and a `state_id` for each provider.  This is done primarily to reduce the
payload size since many of the `Provider`s will share a `State`

```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` query string parameter for the corresponding fields in the JSON
document.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,staes.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/12345?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```



    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

# import models into model package
from .applicant import Applicant
from .base import Base
from .carrier import Carrier
from .carrier_subsidiary import CarrierSubsidiary
from .county import County
from .county_bulk import CountyBulk
from .drug import Drug
from .drug_coverage import DrugCoverage
from .drug_coverage_response import DrugCoverageResponse
from .drug_package import DrugPackage
from .drug_search_response import DrugSearchResponse
from .meta import Meta
from .network import Network
from .network_search_response import NetworkSearchResponse
from .plan import Plan
from .plan_county import PlanCounty
from .plan_county_bulk import PlanCountyBulk
from .plan_search_response import PlanSearchResponse
from .plan_search_result import PlanSearchResult
from .plan_show_response import PlanShowResponse
from .pricing import Pricing
from .provider import Provider
from .provider_show_response import ProviderShowResponse
from .providers_search_response import ProvidersSearchResponse
from .rating_area import RatingArea
from .request_plan_find import RequestPlanFind
from .request_plan_find_applicant import RequestPlanFindApplicant
from .request_plan_find_drug_package import RequestPlanFindDrugPackage
from .request_plan_find_provider import RequestPlanFindProvider
from .request_providers_search import RequestProvidersSearch
from .service_area import ServiceArea
from .service_area_zip_county import ServiceAreaZipCounty
from .state import State
from .zip_code import ZipCode
from .zip_counties_response import ZipCountiesResponse
from .zip_county import ZipCounty
from .zip_county_bulk import ZipCountyBulk
from .zip_county_response import ZipCountyResponse



# coding: utf-8

"""
    Vericred API

    Vericred's API allows you to search for Health Plans that a specific doctor
accepts.

## Getting Started

Visit our [Developer Portal](https://vericred.3scale.net) to
create an account.

Once you have created an account, you can create one Application for
Production and another for our Sandbox (select the appropriate Plan when
you create the Application).

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v3`.  Previous versions are `v1` and `v2`.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v2' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their `State`s
we sideload the associated data.  In this example, we would provide an Array of
`State`s and a `state_id` for each provider.  This is done primarily to reduce the
payload size since many of the `Provider`s will share a `State`

```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` query string parameter for the corresponding fields in the JSON
document.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,staes.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/12345?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```



    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Provider(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, accepting_change_of_payor_patients=None, accepting_medicaid_patients=None, accepting_medicare_patients=None, accepting_private_patients=None, accepting_referral_patients=None, city=None, email=None, gender=None, first_name=None, hios_ids=None, id=None, last_name=None, latitude=None, longitude=None, middle_name=None, network_ids=None, personal_phone=None, phone=None, presentation_name=None, specialty=None, state=None, state_id=None, street_line_1=None, street_line_2=None, suffix=None, title=None, type=None, zip_code=None):
        """
        Provider - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'accepting_change_of_payor_patients': 'bool',
            'accepting_medicaid_patients': 'bool',
            'accepting_medicare_patients': 'bool',
            'accepting_private_patients': 'bool',
            'accepting_referral_patients': 'bool',
            'city': 'str',
            'email': 'str',
            'gender': 'str',
            'first_name': 'str',
            'hios_ids': 'list[str]',
            'id': 'int',
            'last_name': 'str',
            'latitude': 'float',
            'longitude': 'float',
            'middle_name': 'str',
            'network_ids': 'list[int]',
            'personal_phone': 'str',
            'phone': 'str',
            'presentation_name': 'str',
            'specialty': 'str',
            'state': 'str',
            'state_id': 'int',
            'street_line_1': 'str',
            'street_line_2': 'str',
            'suffix': 'str',
            'title': 'str',
            'type': 'str',
            'zip_code': 'str'
        }

        self.attribute_map = {
            'accepting_change_of_payor_patients': 'accepting_change_of_payor_patients',
            'accepting_medicaid_patients': 'accepting_medicaid_patients',
            'accepting_medicare_patients': 'accepting_medicare_patients',
            'accepting_private_patients': 'accepting_private_patients',
            'accepting_referral_patients': 'accepting_referral_patients',
            'city': 'city',
            'email': 'email',
            'gender': 'gender',
            'first_name': 'first_name',
            'hios_ids': 'hios_ids',
            'id': 'id',
            'last_name': 'last_name',
            'latitude': 'latitude',
            'longitude': 'longitude',
            'middle_name': 'middle_name',
            'network_ids': 'network_ids',
            'personal_phone': 'personal_phone',
            'phone': 'phone',
            'presentation_name': 'presentation_name',
            'specialty': 'specialty',
            'state': 'state',
            'state_id': 'state_id',
            'street_line_1': 'street_line_1',
            'street_line_2': 'street_line_2',
            'suffix': 'suffix',
            'title': 'title',
            'type': 'type',
            'zip_code': 'zip_code'
        }

        self._accepting_change_of_payor_patients = accepting_change_of_payor_patients
        self._accepting_medicaid_patients = accepting_medicaid_patients
        self._accepting_medicare_patients = accepting_medicare_patients
        self._accepting_private_patients = accepting_private_patients
        self._accepting_referral_patients = accepting_referral_patients
        self._city = city
        self._email = email
        self._gender = gender
        self._first_name = first_name
        self._hios_ids = hios_ids
        self._id = id
        self._last_name = last_name
        self._latitude = latitude
        self._longitude = longitude
        self._middle_name = middle_name
        self._network_ids = network_ids
        self._personal_phone = personal_phone
        self._phone = phone
        self._presentation_name = presentation_name
        self._specialty = specialty
        self._state = state
        self._state_id = state_id
        self._street_line_1 = street_line_1
        self._street_line_2 = street_line_2
        self._suffix = suffix
        self._title = title
        self._type = type
        self._zip_code = zip_code

    @property
    def accepting_change_of_payor_patients(self):
        """
        Gets the accepting_change_of_payor_patients of this Provider.
        Is this provider accepting patients with a change of insurance?

        :return: The accepting_change_of_payor_patients of this Provider.
        :rtype: bool
        """
        return self._accepting_change_of_payor_patients

    @accepting_change_of_payor_patients.setter
    def accepting_change_of_payor_patients(self, accepting_change_of_payor_patients):
        """
        Sets the accepting_change_of_payor_patients of this Provider.
        Is this provider accepting patients with a change of insurance?

        :param accepting_change_of_payor_patients: The accepting_change_of_payor_patients of this Provider.
        :type: bool
        """

        self._accepting_change_of_payor_patients = accepting_change_of_payor_patients

    @property
    def accepting_medicaid_patients(self):
        """
        Gets the accepting_medicaid_patients of this Provider.
        Is this provider accepting new Medicaid patients?

        :return: The accepting_medicaid_patients of this Provider.
        :rtype: bool
        """
        return self._accepting_medicaid_patients

    @accepting_medicaid_patients.setter
    def accepting_medicaid_patients(self, accepting_medicaid_patients):
        """
        Sets the accepting_medicaid_patients of this Provider.
        Is this provider accepting new Medicaid patients?

        :param accepting_medicaid_patients: The accepting_medicaid_patients of this Provider.
        :type: bool
        """

        self._accepting_medicaid_patients = accepting_medicaid_patients

    @property
    def accepting_medicare_patients(self):
        """
        Gets the accepting_medicare_patients of this Provider.
        Is this provider accepting new Medicare patients?

        :return: The accepting_medicare_patients of this Provider.
        :rtype: bool
        """
        return self._accepting_medicare_patients

    @accepting_medicare_patients.setter
    def accepting_medicare_patients(self, accepting_medicare_patients):
        """
        Sets the accepting_medicare_patients of this Provider.
        Is this provider accepting new Medicare patients?

        :param accepting_medicare_patients: The accepting_medicare_patients of this Provider.
        :type: bool
        """

        self._accepting_medicare_patients = accepting_medicare_patients

    @property
    def accepting_private_patients(self):
        """
        Gets the accepting_private_patients of this Provider.
        Is this provider accepting new patients with private insurance?

        :return: The accepting_private_patients of this Provider.
        :rtype: bool
        """
        return self._accepting_private_patients

    @accepting_private_patients.setter
    def accepting_private_patients(self, accepting_private_patients):
        """
        Sets the accepting_private_patients of this Provider.
        Is this provider accepting new patients with private insurance?

        :param accepting_private_patients: The accepting_private_patients of this Provider.
        :type: bool
        """

        self._accepting_private_patients = accepting_private_patients

    @property
    def accepting_referral_patients(self):
        """
        Gets the accepting_referral_patients of this Provider.
        Is this provider accepting new patients via referrals?

        :return: The accepting_referral_patients of this Provider.
        :rtype: bool
        """
        return self._accepting_referral_patients

    @accepting_referral_patients.setter
    def accepting_referral_patients(self, accepting_referral_patients):
        """
        Sets the accepting_referral_patients of this Provider.
        Is this provider accepting new patients via referrals?

        :param accepting_referral_patients: The accepting_referral_patients of this Provider.
        :type: bool
        """

        self._accepting_referral_patients = accepting_referral_patients

    @property
    def city(self):
        """
        Gets the city of this Provider.
        City name (e.g. Springfield).

        :return: The city of this Provider.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this Provider.
        City name (e.g. Springfield).

        :param city: The city of this Provider.
        :type: str
        """

        self._city = city

    @property
    def email(self):
        """
        Gets the email of this Provider.
        Primary email address to contact the provider.

        :return: The email of this Provider.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this Provider.
        Primary email address to contact the provider.

        :param email: The email of this Provider.
        :type: str
        """

        self._email = email

    @property
    def gender(self):
        """
        Gets the gender of this Provider.
        Provider's gender (M or F)

        :return: The gender of this Provider.
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """
        Sets the gender of this Provider.
        Provider's gender (M or F)

        :param gender: The gender of this Provider.
        :type: str
        """

        self._gender = gender

    @property
    def first_name(self):
        """
        Gets the first_name of this Provider.
        Given name for the provider.

        :return: The first_name of this Provider.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this Provider.
        Given name for the provider.

        :param first_name: The first_name of this Provider.
        :type: str
        """

        self._first_name = first_name

    @property
    def hios_ids(self):
        """
        Gets the hios_ids of this Provider.
        List of HIOS ids for this provider

        :return: The hios_ids of this Provider.
        :rtype: list[str]
        """
        return self._hios_ids

    @hios_ids.setter
    def hios_ids(self, hios_ids):
        """
        Sets the hios_ids of this Provider.
        List of HIOS ids for this provider

        :param hios_ids: The hios_ids of this Provider.
        :type: list[str]
        """

        self._hios_ids = hios_ids

    @property
    def id(self):
        """
        Gets the id of this Provider.
        National Provider Index (NPI) number

        :return: The id of this Provider.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Provider.
        National Provider Index (NPI) number

        :param id: The id of this Provider.
        :type: int
        """

        self._id = id

    @property
    def last_name(self):
        """
        Gets the last_name of this Provider.
        Family name for the provider.

        :return: The last_name of this Provider.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this Provider.
        Family name for the provider.

        :param last_name: The last_name of this Provider.
        :type: str
        """

        self._last_name = last_name

    @property
    def latitude(self):
        """
        Gets the latitude of this Provider.
        Latitude of provider

        :return: The latitude of this Provider.
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """
        Sets the latitude of this Provider.
        Latitude of provider

        :param latitude: The latitude of this Provider.
        :type: float
        """

        self._latitude = latitude

    @property
    def longitude(self):
        """
        Gets the longitude of this Provider.
        Longitude of provider

        :return: The longitude of this Provider.
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """
        Sets the longitude of this Provider.
        Longitude of provider

        :param longitude: The longitude of this Provider.
        :type: float
        """

        self._longitude = longitude

    @property
    def middle_name(self):
        """
        Gets the middle_name of this Provider.
        Middle name for the provider.

        :return: The middle_name of this Provider.
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """
        Sets the middle_name of this Provider.
        Middle name for the provider.

        :param middle_name: The middle_name of this Provider.
        :type: str
        """

        self._middle_name = middle_name

    @property
    def network_ids(self):
        """
        Gets the network_ids of this Provider.
        Array of network ids

        :return: The network_ids of this Provider.
        :rtype: list[int]
        """
        return self._network_ids

    @network_ids.setter
    def network_ids(self, network_ids):
        """
        Sets the network_ids of this Provider.
        Array of network ids

        :param network_ids: The network_ids of this Provider.
        :type: list[int]
        """

        self._network_ids = network_ids

    @property
    def personal_phone(self):
        """
        Gets the personal_phone of this Provider.
        Personal contact phone for the provider.

        :return: The personal_phone of this Provider.
        :rtype: str
        """
        return self._personal_phone

    @personal_phone.setter
    def personal_phone(self, personal_phone):
        """
        Sets the personal_phone of this Provider.
        Personal contact phone for the provider.

        :param personal_phone: The personal_phone of this Provider.
        :type: str
        """

        self._personal_phone = personal_phone

    @property
    def phone(self):
        """
        Gets the phone of this Provider.
        Office phone for the provider

        :return: The phone of this Provider.
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """
        Sets the phone of this Provider.
        Office phone for the provider

        :param phone: The phone of this Provider.
        :type: str
        """

        self._phone = phone

    @property
    def presentation_name(self):
        """
        Gets the presentation_name of this Provider.
        Preferred name for display (e.g. Dr. Francis White may prefer Dr. Frank White)

        :return: The presentation_name of this Provider.
        :rtype: str
        """
        return self._presentation_name

    @presentation_name.setter
    def presentation_name(self, presentation_name):
        """
        Sets the presentation_name of this Provider.
        Preferred name for display (e.g. Dr. Francis White may prefer Dr. Frank White)

        :param presentation_name: The presentation_name of this Provider.
        :type: str
        """

        self._presentation_name = presentation_name

    @property
    def specialty(self):
        """
        Gets the specialty of this Provider.
        Name of the primary Specialty

        :return: The specialty of this Provider.
        :rtype: str
        """
        return self._specialty

    @specialty.setter
    def specialty(self, specialty):
        """
        Sets the specialty of this Provider.
        Name of the primary Specialty

        :param specialty: The specialty of this Provider.
        :type: str
        """

        self._specialty = specialty

    @property
    def state(self):
        """
        Gets the state of this Provider.
        State code for the provider's address (e.g. NY).

        :return: The state of this Provider.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Provider.
        State code for the provider's address (e.g. NY).

        :param state: The state of this Provider.
        :type: str
        """

        self._state = state

    @property
    def state_id(self):
        """
        Gets the state_id of this Provider.
        Foreign key to States

        :return: The state_id of this Provider.
        :rtype: int
        """
        return self._state_id

    @state_id.setter
    def state_id(self, state_id):
        """
        Sets the state_id of this Provider.
        Foreign key to States

        :param state_id: The state_id of this Provider.
        :type: int
        """

        self._state_id = state_id

    @property
    def street_line_1(self):
        """
        Gets the street_line_1 of this Provider.
        First line of the provider's street address.

        :return: The street_line_1 of this Provider.
        :rtype: str
        """
        return self._street_line_1

    @street_line_1.setter
    def street_line_1(self, street_line_1):
        """
        Sets the street_line_1 of this Provider.
        First line of the provider's street address.

        :param street_line_1: The street_line_1 of this Provider.
        :type: str
        """

        self._street_line_1 = street_line_1

    @property
    def street_line_2(self):
        """
        Gets the street_line_2 of this Provider.
        Second line of the provider's street address.

        :return: The street_line_2 of this Provider.
        :rtype: str
        """
        return self._street_line_2

    @street_line_2.setter
    def street_line_2(self, street_line_2):
        """
        Sets the street_line_2 of this Provider.
        Second line of the provider's street address.

        :param street_line_2: The street_line_2 of this Provider.
        :type: str
        """

        self._street_line_2 = street_line_2

    @property
    def suffix(self):
        """
        Gets the suffix of this Provider.
        Suffix for the provider's name (e.g. Jr)

        :return: The suffix of this Provider.
        :rtype: str
        """
        return self._suffix

    @suffix.setter
    def suffix(self, suffix):
        """
        Sets the suffix of this Provider.
        Suffix for the provider's name (e.g. Jr)

        :param suffix: The suffix of this Provider.
        :type: str
        """

        self._suffix = suffix

    @property
    def title(self):
        """
        Gets the title of this Provider.
        Professional title for the provider (e.g. Dr).

        :return: The title of this Provider.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this Provider.
        Professional title for the provider (e.g. Dr).

        :param title: The title of this Provider.
        :type: str
        """

        self._title = title

    @property
    def type(self):
        """
        Gets the type of this Provider.
        Type of NPI number (individual provider vs organization).

        :return: The type of this Provider.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Provider.
        Type of NPI number (individual provider vs organization).

        :param type: The type of this Provider.
        :type: str
        """

        self._type = type

    @property
    def zip_code(self):
        """
        Gets the zip_code of this Provider.
        Postal code for the provider's address (e.g. 11215)

        :return: The zip_code of this Provider.
        :rtype: str
        """
        return self._zip_code

    @zip_code.setter
    def zip_code(self, zip_code):
        """
        Sets the zip_code of this Provider.
        Postal code for the provider's address (e.g. 11215)

        :param zip_code: The zip_code of this Provider.
        :type: str
        """

        self._zip_code = zip_code

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Vericred API

    Vericred's API allows you to search for Health Plans that a specific doctor
accepts.

## Getting Started

Visit our [Developer Portal](https://vericred.3scale.net) to
create an account.

Once you have created an account, you can create one Application for
Production and another for our Sandbox (select the appropriate Plan when
you create the Application).

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v3`.  Previous versions are `v1` and `v2`.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v2' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their `State`s
we sideload the associated data.  In this example, we would provide an Array of
`State`s and a `state_id` for each provider.  This is done primarily to reduce the
payload size since many of the `Provider`s will share a `State`

```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` query string parameter for the corresponding fields in the JSON
document.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,staes.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/12345?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```



    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Applicant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, dob=None, member_id=None, name=None, relationship=None, smoker=None, ssn=None):
        """
        Applicant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'dob': 'date',
            'member_id': 'str',
            'name': 'str',
            'relationship': 'str',
            'smoker': 'bool',
            'ssn': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'dob': 'dob',
            'member_id': 'member_id',
            'name': 'name',
            'relationship': 'relationship',
            'smoker': 'smoker',
            'ssn': 'ssn'
        }

        self._id = id
        self._dob = dob
        self._member_id = member_id
        self._name = name
        self._relationship = relationship
        self._smoker = smoker
        self._ssn = ssn

    @property
    def id(self):
        """
        Gets the id of this Applicant.
        Primary key

        :return: The id of this Applicant.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Applicant.
        Primary key

        :param id: The id of this Applicant.
        :type: int
        """

        self._id = id

    @property
    def dob(self):
        """
        Gets the dob of this Applicant.
        Date of Birth

        :return: The dob of this Applicant.
        :rtype: date
        """
        return self._dob

    @dob.setter
    def dob(self, dob):
        """
        Sets the dob of this Applicant.
        Date of Birth

        :param dob: The dob of this Applicant.
        :type: date
        """

        self._dob = dob

    @property
    def member_id(self):
        """
        Gets the member_id of this Applicant.
        Member token

        :return: The member_id of this Applicant.
        :rtype: str
        """
        return self._member_id

    @member_id.setter
    def member_id(self, member_id):
        """
        Sets the member_id of this Applicant.
        Member token

        :param member_id: The member_id of this Applicant.
        :type: str
        """

        self._member_id = member_id

    @property
    def name(self):
        """
        Gets the name of this Applicant.
        Full name of the Applicant

        :return: The name of this Applicant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Applicant.
        Full name of the Applicant

        :param name: The name of this Applicant.
        :type: str
        """

        self._name = name

    @property
    def relationship(self):
        """
        Gets the relationship of this Applicant.
        Relationship of the Applicant to the Member

        :return: The relationship of this Applicant.
        :rtype: str
        """
        return self._relationship

    @relationship.setter
    def relationship(self, relationship):
        """
        Sets the relationship of this Applicant.
        Relationship of the Applicant to the Member

        :param relationship: The relationship of this Applicant.
        :type: str
        """

        self._relationship = relationship

    @property
    def smoker(self):
        """
        Gets the smoker of this Applicant.
        Does the Applicant smoke?

        :return: The smoker of this Applicant.
        :rtype: bool
        """
        return self._smoker

    @smoker.setter
    def smoker(self, smoker):
        """
        Sets the smoker of this Applicant.
        Does the Applicant smoke?

        :param smoker: The smoker of this Applicant.
        :type: bool
        """

        self._smoker = smoker

    @property
    def ssn(self):
        """
        Gets the ssn of this Applicant.
        Applicant's Social Security Number

        :return: The ssn of this Applicant.
        :rtype: str
        """
        return self._ssn

    @ssn.setter
    def ssn(self, ssn):
        """
        Sets the ssn of this Applicant.
        Applicant's Social Security Number

        :param ssn: The ssn of this Applicant.
        :type: str
        """

        self._ssn = ssn

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Vericred API

    Vericred's API allows you to search for Health Plans that a specific doctor
accepts.

## Getting Started

Visit our [Developer Portal](https://vericred.3scale.net) to
create an account.

Once you have created an account, you can create one Application for
Production and another for our Sandbox (select the appropriate Plan when
you create the Application).

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v3`.  Previous versions are `v1` and `v2`.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v2' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their `State`s
we sideload the associated data.  In this example, we would provide an Array of
`State`s and a `state_id` for each provider.  This is done primarily to reduce the
payload size since many of the `Provider`s will share a `State`

```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` query string parameter for the corresponding fields in the JSON
document.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,staes.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/12345?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```



    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class PlansApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def find_plans(self, **kwargs):
        """
        Find Plans
        ### Location Information  Searching for a set of plans requires a `zip_code` and `fips_code` code.  These are used to determine pricing and availabity of health plans. This endpoint is paginated.  Optionally, you may provide a list of Applicants or Providers  ### Applicants  This is a list of people who will be covered by the plan.  We use this list to calculate the premium.  You must include `age` and can include `smoker`, which also factors into pricing in some states.  Applicants *must* include an age.  If smoker is omitted, its value is assumed to be false.  #### Multiple Applicants To get pricing for multiple applicants, just append multiple sets of data to the URL with the age and smoking status of each applicant next to each other.  For example, given two applicants - one age 32 and a non-smoker and one age 29 and a smoker, you could use the following request  `GET /plans?zip_code=07451&fips_code=33025&applicants[][age]=32&applicants[][age]=29&applicants[][smoker]=true`  It would also be acceptible to include `applicants[][smoker]=false` after the first applicant's age.  ### Providers  We identify Providers (Doctors) by their National Practitioner Index number (NPI).  If you pass a list of Providers, keyed by their NPI number, we will return a list of which Providers are in and out of network for each plan returned.  For example, if we had two providers with the NPI numbers `12345` and `23456` you would make the following request  `GET /plans?zip_code=07451&fips_code=33025&providers[][npi]=12345&providers[][npi]=23456`  ### Enrollment Date  To calculate plan pricing and availability, we default to the current date as the enrollment date.  To specify a date in the future (or the past), pass a string with the format `YYYY-MM-DD` in the `enrollment_date` parameter.  `GET /plans?zip_code=07451&fips_code=33025&enrollment_date=2016-01-01`  ### Subsidy  On-marketplace plans are eligible for a subsidy based on the `household_size` and `household_income` of the applicants.  If you pass those values, we will calculate the `subsidized_premium` and return it for each plan.  If no values are provided, the `subsidized_premium` will be the same as the `premium`  `GET /plans?zip_code=07451&fips_code=33025&household_size=4&household_income=40000`   ### Sorting  Plans can be sorted by the `premium`, `carrier_name`, `level`, and `plan_type` fields, by either ascending (as `asc`) or descending (as `dsc) sort under the `sort` field.  For example, to sort plans by level, the sort parameter would be `level:asc`. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_plans(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RequestPlanFind body: 
        :return: PlanSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.find_plans_with_http_info(**kwargs)
        else:
            (data) = self.find_plans_with_http_info(**kwargs)
            return data

    def find_plans_with_http_info(self, **kwargs):
        """
        Find Plans
        ### Location Information  Searching for a set of plans requires a `zip_code` and `fips_code` code.  These are used to determine pricing and availabity of health plans. This endpoint is paginated.  Optionally, you may provide a list of Applicants or Providers  ### Applicants  This is a list of people who will be covered by the plan.  We use this list to calculate the premium.  You must include `age` and can include `smoker`, which also factors into pricing in some states.  Applicants *must* include an age.  If smoker is omitted, its value is assumed to be false.  #### Multiple Applicants To get pricing for multiple applicants, just append multiple sets of data to the URL with the age and smoking status of each applicant next to each other.  For example, given two applicants - one age 32 and a non-smoker and one age 29 and a smoker, you could use the following request  `GET /plans?zip_code=07451&fips_code=33025&applicants[][age]=32&applicants[][age]=29&applicants[][smoker]=true`  It would also be acceptible to include `applicants[][smoker]=false` after the first applicant's age.  ### Providers  We identify Providers (Doctors) by their National Practitioner Index number (NPI).  If you pass a list of Providers, keyed by their NPI number, we will return a list of which Providers are in and out of network for each plan returned.  For example, if we had two providers with the NPI numbers `12345` and `23456` you would make the following request  `GET /plans?zip_code=07451&fips_code=33025&providers[][npi]=12345&providers[][npi]=23456`  ### Enrollment Date  To calculate plan pricing and availability, we default to the current date as the enrollment date.  To specify a date in the future (or the past), pass a string with the format `YYYY-MM-DD` in the `enrollment_date` parameter.  `GET /plans?zip_code=07451&fips_code=33025&enrollment_date=2016-01-01`  ### Subsidy  On-marketplace plans are eligible for a subsidy based on the `household_size` and `household_income` of the applicants.  If you pass those values, we will calculate the `subsidized_premium` and return it for each plan.  If no values are provided, the `subsidized_premium` will be the same as the `premium`  `GET /plans?zip_code=07451&fips_code=33025&household_size=4&household_income=40000`   ### Sorting  Plans can be sorted by the `premium`, `carrier_name`, `level`, and `plan_type` fields, by either ascending (as `asc`) or descending (as `dsc) sort under the `sort` field.  For example, to sort plans by level, the sort parameter would be `level:asc`. 

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.find_plans_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RequestPlanFind body: 
        :return: PlanSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_plans" % key
                )
            params[key] = val
        del params['kwargs']

        resource_path = '/plans/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept([])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Vericred-Api-Key']

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='PlanSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def show_plan(self, **kwargs):
        """
        Show Plan
        Show the details of an individual Plan.  This includes deductibles, maximums out of pocket, and co-pay/coinsurance for benefits

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.show_plan(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int year: Plan year (defaults to current year)
        :return: PlanShowResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.show_plan_with_http_info(**kwargs)
        else:
            (data) = self.show_plan_with_http_info(**kwargs)
            return data

    def show_plan_with_http_info(self, **kwargs):
        """
        Show Plan
        Show the details of an individual Plan.  This includes deductibles, maximums out of pocket, and co-pay/coinsurance for benefits

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.show_plan_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int year: Plan year (defaults to current year)
        :return: PlanShowResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method show_plan" % key
                )
            params[key] = val
        del params['kwargs']

        resource_path = '/plans/{id}'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'year' in params:
            query_params['year'] = params['year']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Vericred-Api-Key']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='PlanShowResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))



# coding: utf-8

"""
    Vericred API

    Vericred's API allows you to search for Health Plans that a specific doctor
accepts.

## Getting Started

Visit our [Developer Portal](https://vericred.3scale.net) to
create an account.

Once you have created an account, you can create one Application for
Production and another for our Sandbox (select the appropriate Plan when
you create the Application).

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v3`.  Previous versions are `v1` and `v2`.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v2' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their `State`s
we sideload the associated data.  In this example, we would provide an Array of
`State`s and a `state_id` for each provider.  This is done primarily to reduce the
payload size since many of the `Provider`s will share a `State`

```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` query string parameter for the corresponding fields in the JSON
document.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,staes.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/12345?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```



    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class RequestPlanFind(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, applicants=None, enrollment_date=None, drug_packages=None, fips_code=None, household_income=None, household_size=None, ids=None, market=None, providers=None, page=None, per_page=None, sort=None, zip_code=None):
        """
        RequestPlanFind - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'applicants': 'list[RequestPlanFindApplicant]',
            'enrollment_date': 'str',
            'drug_packages': 'list[RequestPlanFindDrugPackage]',
            'fips_code': 'str',
            'household_income': 'int',
            'household_size': 'int',
            'ids': 'list[int]',
            'market': 'str',
            'providers': 'list[RequestPlanFindProvider]',
            'page': 'int',
            'per_page': 'int',
            'sort': 'str',
            'zip_code': 'str'
        }

        self.attribute_map = {
            'applicants': 'applicants',
            'enrollment_date': 'enrollment_date',
            'drug_packages': 'drug_packages',
            'fips_code': 'fips_code',
            'household_income': 'household_income',
            'household_size': 'household_size',
            'ids': 'ids',
            'market': 'market',
            'providers': 'providers',
            'page': 'page',
            'per_page': 'per_page',
            'sort': 'sort',
            'zip_code': 'zip_code'
        }

        self._applicants = applicants
        self._enrollment_date = enrollment_date
        self._drug_packages = drug_packages
        self._fips_code = fips_code
        self._household_income = household_income
        self._household_size = household_size
        self._ids = ids
        self._market = market
        self._providers = providers
        self._page = page
        self._per_page = per_page
        self._sort = sort
        self._zip_code = zip_code

    @property
    def applicants(self):
        """
        Gets the applicants of this RequestPlanFind.
        Applicants for desired plans.

        :return: The applicants of this RequestPlanFind.
        :rtype: list[RequestPlanFindApplicant]
        """
        return self._applicants

    @applicants.setter
    def applicants(self, applicants):
        """
        Sets the applicants of this RequestPlanFind.
        Applicants for desired plans.

        :param applicants: The applicants of this RequestPlanFind.
        :type: list[RequestPlanFindApplicant]
        """

        self._applicants = applicants

    @property
    def enrollment_date(self):
        """
        Gets the enrollment_date of this RequestPlanFind.
        Date of enrollment

        :return: The enrollment_date of this RequestPlanFind.
        :rtype: str
        """
        return self._enrollment_date

    @enrollment_date.setter
    def enrollment_date(self, enrollment_date):
        """
        Sets the enrollment_date of this RequestPlanFind.
        Date of enrollment

        :param enrollment_date: The enrollment_date of this RequestPlanFind.
        :type: str
        """

        self._enrollment_date = enrollment_date

    @property
    def drug_packages(self):
        """
        Gets the drug_packages of this RequestPlanFind.
        National Drug Code Package Id

        :return: The drug_packages of this RequestPlanFind.
        :rtype: list[RequestPlanFindDrugPackage]
        """
        return self._drug_packages

    @drug_packages.setter
    def drug_packages(self, drug_packages):
        """
        Sets the drug_packages of this RequestPlanFind.
        National Drug Code Package Id

        :param drug_packages: The drug_packages of this RequestPlanFind.
        :type: list[RequestPlanFindDrugPackage]
        """

        self._drug_packages = drug_packages

    @property
    def fips_code(self):
        """
        Gets the fips_code of this RequestPlanFind.
        County code to determine eligibility

        :return: The fips_code of this RequestPlanFind.
        :rtype: str
        """
        return self._fips_code

    @fips_code.setter
    def fips_code(self, fips_code):
        """
        Sets the fips_code of this RequestPlanFind.
        County code to determine eligibility

        :param fips_code: The fips_code of this RequestPlanFind.
        :type: str
        """

        self._fips_code = fips_code

    @property
    def household_income(self):
        """
        Gets the household_income of this RequestPlanFind.
        Total household income.

        :return: The household_income of this RequestPlanFind.
        :rtype: int
        """
        return self._household_income

    @household_income.setter
    def household_income(self, household_income):
        """
        Sets the household_income of this RequestPlanFind.
        Total household income.

        :param household_income: The household_income of this RequestPlanFind.
        :type: int
        """

        self._household_income = household_income

    @property
    def household_size(self):
        """
        Gets the household_size of this RequestPlanFind.
        Number of people living in household.

        :return: The household_size of this RequestPlanFind.
        :rtype: int
        """
        return self._household_size

    @household_size.setter
    def household_size(self, household_size):
        """
        Sets the household_size of this RequestPlanFind.
        Number of people living in household.

        :param household_size: The household_size of this RequestPlanFind.
        :type: int
        """

        self._household_size = household_size

    @property
    def ids(self):
        """
        Gets the ids of this RequestPlanFind.
        List of plan IDs to filter by

        :return: The ids of this RequestPlanFind.
        :rtype: list[int]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """
        Sets the ids of this RequestPlanFind.
        List of plan IDs to filter by

        :param ids: The ids of this RequestPlanFind.
        :type: list[int]
        """

        self._ids = ids

    @property
    def market(self):
        """
        Gets the market of this RequestPlanFind.
        Type of plan to search for.

        :return: The market of this RequestPlanFind.
        :rtype: str
        """
        return self._market

    @market.setter
    def market(self, market):
        """
        Sets the market of this RequestPlanFind.
        Type of plan to search for.

        :param market: The market of this RequestPlanFind.
        :type: str
        """

        self._market = market

    @property
    def providers(self):
        """
        Gets the providers of this RequestPlanFind.
        List of providers to search for.

        :return: The providers of this RequestPlanFind.
        :rtype: list[RequestPlanFindProvider]
        """
        return self._providers

    @providers.setter
    def providers(self, providers):
        """
        Sets the providers of this RequestPlanFind.
        List of providers to search for.

        :param providers: The providers of this RequestPlanFind.
        :type: list[RequestPlanFindProvider]
        """

        self._providers = providers

    @property
    def page(self):
        """
        Gets the page of this RequestPlanFind.
        Selected page of paginated response.

        :return: The page of this RequestPlanFind.
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """
        Sets the page of this RequestPlanFind.
        Selected page of paginated response.

        :param page: The page of this RequestPlanFind.
        :type: int
        """

        self._page = page

    @property
    def per_page(self):
        """
        Gets the per_page of this RequestPlanFind.
        Results per page of response.

        :return: The per_page of this RequestPlanFind.
        :rtype: int
        """
        return self._per_page

    @per_page.setter
    def per_page(self, per_page):
        """
        Sets the per_page of this RequestPlanFind.
        Results per page of response.

        :param per_page: The per_page of this RequestPlanFind.
        :type: int
        """

        self._per_page = per_page

    @property
    def sort(self):
        """
        Gets the sort of this RequestPlanFind.
        Sort responses by plan field.

        :return: The sort of this RequestPlanFind.
        :rtype: str
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """
        Sets the sort of this RequestPlanFind.
        Sort responses by plan field.

        :param sort: The sort of this RequestPlanFind.
        :type: str
        """

        self._sort = sort

    @property
    def zip_code(self):
        """
        Gets the zip_code of this RequestPlanFind.
        5-digit zip code - this helps determine pricing.

        :return: The zip_code of this RequestPlanFind.
        :rtype: str
        """
        return self._zip_code

    @zip_code.setter
    def zip_code(self, zip_code):
        """
        Sets the zip_code of this RequestPlanFind.
        5-digit zip code - this helps determine pricing.

        :param zip_code: The zip_code of this RequestPlanFind.
        :type: str
        """

        self._zip_code = zip_code

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Vericred API

    Vericred's API allows you to search for Health Plans that a specific doctor
accepts.

## Getting Started

Visit our [Developer Portal](https://vericred.3scale.net) to
create an account.

Once you have created an account, you can create one Application for
Production and another for our Sandbox (select the appropriate Plan when
you create the Application).

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v3`.  Previous versions are `v1` and `v2`.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v2' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their `State`s
we sideload the associated data.  In this example, we would provide an Array of
`State`s and a `state_id` for each provider.  This is done primarily to reduce the
payload size since many of the `Provider`s will share a `State`

```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` query string parameter for the corresponding fields in the JSON
document.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,staes.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/12345?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```



    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import unittest

import vericred_client
from vericred_client.rest import ApiException
from vericred_client.models.plan import Plan


class TestPlan(unittest.TestCase):
    """ Plan unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPlan(self):
        """
        Test Plan
        """
        model = vericred_client.models.plan.Plan()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Vericred API

    Vericred's API allows you to search for Health Plans that a specific doctor
accepts.

## Getting Started

Visit our [Developer Portal](https://vericred.3scale.net) to
create an account.

Once you have created an account, you can create one Application for
Production and another for our Sandbox (select the appropriate Plan when
you create the Application).

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v3`.  Previous versions are `v1` and `v2`.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v2' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their `State`s
we sideload the associated data.  In this example, we would provide an Array of
`State`s and a `state_id` for each provider.  This is done primarily to reduce the
payload size since many of the `Provider`s will share a `State`

```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` query string parameter for the corresponding fields in the JSON
document.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,staes.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/12345?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```



    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Plan(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, adult_dental=None, age29_rider=None, ambulance=None, benefits_summary_url=None, buy_link=None, carrier_name=None, child_dental=None, child_eyewear=None, child_eye_exam=None, customer_service_phone_number=None, durable_medical_equipment=None, diagnostic_test=None, display_name=None, dp_rider=None, drug_formulary_url=None, effective_date=None, expiration_date=None, emergency_room=None, family_drug_deductible=None, family_drug_moop=None, family_medical_deductible=None, family_medical_moop=None, fp_rider=None, generic_drugs=None, habilitation_services=None, hios_issuer_id=None, home_health_care=None, hospice_service=None, hsa_eligible=None, id=None, imaging=None, in_network_ids=None, individual_drug_deductible=None, individual_drug_moop=None, individual_medical_deductible=None, individual_medical_moop=None, inpatient_birth=None, inpatient_facility=None, inpatient_mental_health=None, inpatient_physician=None, inpatient_substance=None, level=None, logo_url=None, name=None, network_size=None, non_preferred_brand_drugs=None, on_market=None, off_market=None, out_of_network_coverage=None, out_of_network_ids=None, outpatient_facility=None, outpatient_mental_health=None, outpatient_physician=None, outpatient_substance=None, plan_market=None, plan_type=None, preferred_brand_drugs=None, prenatal_postnatal_care=None, preventative_care=None, premium_subsidized=None, premium=None, primary_care_physician=None, rehabilitation_services=None, service_area_id=None, skilled_nursing=None, specialist=None, specialty_drugs=None, urgent_care=None):
        """
        Plan - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'adult_dental': 'bool',
            'age29_rider': 'bool',
            'ambulance': 'str',
            'benefits_summary_url': 'str',
            'buy_link': 'str',
            'carrier_name': 'str',
            'child_dental': 'bool',
            'child_eyewear': 'str',
            'child_eye_exam': 'str',
            'customer_service_phone_number': 'str',
            'durable_medical_equipment': 'str',
            'diagnostic_test': 'str',
            'display_name': 'str',
            'dp_rider': 'bool',
            'drug_formulary_url': 'str',
            'effective_date': 'str',
            'expiration_date': 'str',
            'emergency_room': 'str',
            'family_drug_deductible': 'str',
            'family_drug_moop': 'str',
            'family_medical_deductible': 'str',
            'family_medical_moop': 'str',
            'fp_rider': 'bool',
            'generic_drugs': 'str',
            'habilitation_services': 'str',
            'hios_issuer_id': 'str',
            'home_health_care': 'str',
            'hospice_service': 'str',
            'hsa_eligible': 'bool',
            'id': 'str',
            'imaging': 'str',
            'in_network_ids': 'list[int]',
            'individual_drug_deductible': 'str',
            'individual_drug_moop': 'str',
            'individual_medical_deductible': 'str',
            'individual_medical_moop': 'str',
            'inpatient_birth': 'str',
            'inpatient_facility': 'str',
            'inpatient_mental_health': 'str',
            'inpatient_physician': 'str',
            'inpatient_substance': 'str',
            'level': 'str',
            'logo_url': 'str',
            'name': 'str',
            'network_size': 'int',
            'non_preferred_brand_drugs': 'str',
            'on_market': 'bool',
            'off_market': 'bool',
            'out_of_network_coverage': 'bool',
            'out_of_network_ids': 'list[int]',
            'outpatient_facility': 'str',
            'outpatient_mental_health': 'str',
            'outpatient_physician': 'str',
            'outpatient_substance': 'str',
            'plan_market': 'str',
            'plan_type': 'str',
            'preferred_brand_drugs': 'str',
            'prenatal_postnatal_care': 'str',
            'preventative_care': 'str',
            'premium_subsidized': 'float',
            'premium': 'float',
            'primary_care_physician': 'str',
            'rehabilitation_services': 'str',
            'service_area_id': 'str',
            'skilled_nursing': 'str',
            'specialist': 'str',
            'specialty_drugs': 'str',
            'urgent_care': 'str'
        }

        self.attribute_map = {
            'adult_dental': 'adult_dental',
            'age29_rider': 'age29_rider',
            'ambulance': 'ambulance',
            'benefits_summary_url': 'benefits_summary_url',
            'buy_link': 'buy_link',
            'carrier_name': 'carrier_name',
            'child_dental': 'child_dental',
            'child_eyewear': 'child_eyewear',
            'child_eye_exam': 'child_eye_exam',
            'customer_service_phone_number': 'customer_service_phone_number',
            'durable_medical_equipment': 'durable_medical_equipment',
            'diagnostic_test': 'diagnostic_test',
            'display_name': 'display_name',
            'dp_rider': 'dp_rider',
            'drug_formulary_url': 'drug_formulary_url',
            'effective_date': 'effective_date',
            'expiration_date': 'expiration_date',
            'emergency_room': 'emergency_room',
            'family_drug_deductible': 'family_drug_deductible',
            'family_drug_moop': 'family_drug_moop',
            'family_medical_deductible': 'family_medical_deductible',
            'family_medical_moop': 'family_medical_moop',
            'fp_rider': 'fp_rider',
            'generic_drugs': 'generic_drugs',
            'habilitation_services': 'habilitation_services',
            'hios_issuer_id': 'hios_issuer_id',
            'home_health_care': 'home_health_care',
            'hospice_service': 'hospice_service',
            'hsa_eligible': 'hsa_eligible',
            'id': 'id',
            'imaging': 'imaging',
            'in_network_ids': 'in_network_ids',
            'individual_drug_deductible': 'individual_drug_deductible',
            'individual_drug_moop': 'individual_drug_moop',
            'individual_medical_deductible': 'individual_medical_deductible',
            'individual_medical_moop': 'individual_medical_moop',
            'inpatient_birth': 'inpatient_birth',
            'inpatient_facility': 'inpatient_facility',
            'inpatient_mental_health': 'inpatient_mental_health',
            'inpatient_physician': 'inpatient_physician',
            'inpatient_substance': 'inpatient_substance',
            'level': 'level',
            'logo_url': 'logo_url',
            'name': 'name',
            'network_size': 'network_size',
            'non_preferred_brand_drugs': 'non_preferred_brand_drugs',
            'on_market': 'on_market',
            'off_market': 'off_market',
            'out_of_network_coverage': 'out_of_network_coverage',
            'out_of_network_ids': 'out_of_network_ids',
            'outpatient_facility': 'outpatient_facility',
            'outpatient_mental_health': 'outpatient_mental_health',
            'outpatient_physician': 'outpatient_physician',
            'outpatient_substance': 'outpatient_substance',
            'plan_market': 'plan_market',
            'plan_type': 'plan_type',
            'preferred_brand_drugs': 'preferred_brand_drugs',
            'prenatal_postnatal_care': 'prenatal_postnatal_care',
            'preventative_care': 'preventative_care',
            'premium_subsidized': 'premium_subsidized',
            'premium': 'premium',
            'primary_care_physician': 'primary_care_physician',
            'rehabilitation_services': 'rehabilitation_services',
            'service_area_id': 'service_area_id',
            'skilled_nursing': 'skilled_nursing',
            'specialist': 'specialist',
            'specialty_drugs': 'specialty_drugs',
            'urgent_care': 'urgent_care'
        }

        self._adult_dental = adult_dental
        self._age29_rider = age29_rider
        self._ambulance = ambulance
        self._benefits_summary_url = benefits_summary_url
        self._buy_link = buy_link
        self._carrier_name = carrier_name
        self._child_dental = child_dental
        self._child_eyewear = child_eyewear
        self._child_eye_exam = child_eye_exam
        self._customer_service_phone_number = customer_service_phone_number
        self._durable_medical_equipment = durable_medical_equipment
        self._diagnostic_test = diagnostic_test
        self._display_name = display_name
        self._dp_rider = dp_rider
        self._drug_formulary_url = drug_formulary_url
        self._effective_date = effective_date
        self._expiration_date = expiration_date
        self._emergency_room = emergency_room
        self._family_drug_deductible = family_drug_deductible
        self._family_drug_moop = family_drug_moop
        self._family_medical_deductible = family_medical_deductible
        self._family_medical_moop = family_medical_moop
        self._fp_rider = fp_rider
        self._generic_drugs = generic_drugs
        self._habilitation_services = habilitation_services
        self._hios_issuer_id = hios_issuer_id
        self._home_health_care = home_health_care
        self._hospice_service = hospice_service
        self._hsa_eligible = hsa_eligible
        self._id = id
        self._imaging = imaging
        self._in_network_ids = in_network_ids
        self._individual_drug_deductible = individual_drug_deductible
        self._individual_drug_moop = individual_drug_moop
        self._individual_medical_deductible = individual_medical_deductible
        self._individual_medical_moop = individual_medical_moop
        self._inpatient_birth = inpatient_birth
        self._inpatient_facility = inpatient_facility
        self._inpatient_mental_health = inpatient_mental_health
        self._inpatient_physician = inpatient_physician
        self._inpatient_substance = inpatient_substance
        self._level = level
        self._logo_url = logo_url
        self._name = name
        self._network_size = network_size
        self._non_preferred_brand_drugs = non_preferred_brand_drugs
        self._on_market = on_market
        self._off_market = off_market
        self._out_of_network_coverage = out_of_network_coverage
        self._out_of_network_ids = out_of_network_ids
        self._outpatient_facility = outpatient_facility
        self._outpatient_mental_health = outpatient_mental_health
        self._outpatient_physician = outpatient_physician
        self._outpatient_substance = outpatient_substance
        self._plan_market = plan_market
        self._plan_type = plan_type
        self._preferred_brand_drugs = preferred_brand_drugs
        self._prenatal_postnatal_care = prenatal_postnatal_care
        self._preventative_care = preventative_care
        self._premium_subsidized = premium_subsidized
        self._premium = premium
        self._primary_care_physician = primary_care_physician
        self._rehabilitation_services = rehabilitation_services
        self._service_area_id = service_area_id
        self._skilled_nursing = skilled_nursing
        self._specialist = specialist
        self._specialty_drugs = specialty_drugs
        self._urgent_care = urgent_care

    @property
    def adult_dental(self):
        """
        Gets the adult_dental of this Plan.
        Does the plan provide dental coverage for adults?

        :return: The adult_dental of this Plan.
        :rtype: bool
        """
        return self._adult_dental

    @adult_dental.setter
    def adult_dental(self, adult_dental):
        """
        Sets the adult_dental of this Plan.
        Does the plan provide dental coverage for adults?

        :param adult_dental: The adult_dental of this Plan.
        :type: bool
        """

        self._adult_dental = adult_dental

    @property
    def age29_rider(self):
        """
        Gets the age29_rider of this Plan.
        

        :return: The age29_rider of this Plan.
        :rtype: bool
        """
        return self._age29_rider

    @age29_rider.setter
    def age29_rider(self, age29_rider):
        """
        Sets the age29_rider of this Plan.
        

        :param age29_rider: The age29_rider of this Plan.
        :type: bool
        """

        self._age29_rider = age29_rider

    @property
    def ambulance(self):
        """
        Gets the ambulance of this Plan.
        Benefits string for ambulance coverage

        :return: The ambulance of this Plan.
        :rtype: str
        """
        return self._ambulance

    @ambulance.setter
    def ambulance(self, ambulance):
        """
        Sets the ambulance of this Plan.
        Benefits string for ambulance coverage

        :param ambulance: The ambulance of this Plan.
        :type: str
        """

        self._ambulance = ambulance

    @property
    def benefits_summary_url(self):
        """
        Gets the benefits_summary_url of this Plan.
        Link to the summary of benefits and coverage (SBC) document.

        :return: The benefits_summary_url of this Plan.
        :rtype: str
        """
        return self._benefits_summary_url

    @benefits_summary_url.setter
    def benefits_summary_url(self, benefits_summary_url):
        """
        Sets the benefits_summary_url of this Plan.
        Link to the summary of benefits and coverage (SBC) document.

        :param benefits_summary_url: The benefits_summary_url of this Plan.
        :type: str
        """

        self._benefits_summary_url = benefits_summary_url

    @property
    def buy_link(self):
        """
        Gets the buy_link of this Plan.
        Link to a location to purchase the plan.

        :return: The buy_link of this Plan.
        :rtype: str
        """
        return self._buy_link

    @buy_link.setter
    def buy_link(self, buy_link):
        """
        Sets the buy_link of this Plan.
        Link to a location to purchase the plan.

        :param buy_link: The buy_link of this Plan.
        :type: str
        """

        self._buy_link = buy_link

    @property
    def carrier_name(self):
        """
        Gets the carrier_name of this Plan.
        Name of the insurance carrier

        :return: The carrier_name of this Plan.
        :rtype: str
        """
        return self._carrier_name

    @carrier_name.setter
    def carrier_name(self, carrier_name):
        """
        Sets the carrier_name of this Plan.
        Name of the insurance carrier

        :param carrier_name: The carrier_name of this Plan.
        :type: str
        """

        self._carrier_name = carrier_name

    @property
    def child_dental(self):
        """
        Gets the child_dental of this Plan.
        Does the plan provide dental coverage for children?

        :return: The child_dental of this Plan.
        :rtype: bool
        """
        return self._child_dental

    @child_dental.setter
    def child_dental(self, child_dental):
        """
        Sets the child_dental of this Plan.
        Does the plan provide dental coverage for children?

        :param child_dental: The child_dental of this Plan.
        :type: bool
        """

        self._child_dental = child_dental

    @property
    def child_eyewear(self):
        """
        Gets the child_eyewear of this Plan.
        Child eyewear benefits summary

        :return: The child_eyewear of this Plan.
        :rtype: str
        """
        return self._child_eyewear

    @child_eyewear.setter
    def child_eyewear(self, child_eyewear):
        """
        Sets the child_eyewear of this Plan.
        Child eyewear benefits summary

        :param child_eyewear: The child_eyewear of this Plan.
        :type: str
        """

        self._child_eyewear = child_eyewear

    @property
    def child_eye_exam(self):
        """
        Gets the child_eye_exam of this Plan.
        Child eye exam benefits summary

        :return: The child_eye_exam of this Plan.
        :rtype: str
        """
        return self._child_eye_exam

    @child_eye_exam.setter
    def child_eye_exam(self, child_eye_exam):
        """
        Sets the child_eye_exam of this Plan.
        Child eye exam benefits summary

        :param child_eye_exam: The child_eye_exam of this Plan.
        :type: str
        """

        self._child_eye_exam = child_eye_exam

    @property
    def customer_service_phone_number(self):
        """
        Gets the customer_service_phone_number of this Plan.
        Phone number to contact the insurance carrier

        :return: The customer_service_phone_number of this Plan.
        :rtype: str
        """
        return self._customer_service_phone_number

    @customer_service_phone_number.setter
    def customer_service_phone_number(self, customer_service_phone_number):
        """
        Sets the customer_service_phone_number of this Plan.
        Phone number to contact the insurance carrier

        :param customer_service_phone_number: The customer_service_phone_number of this Plan.
        :type: str
        """

        self._customer_service_phone_number = customer_service_phone_number

    @property
    def durable_medical_equipment(self):
        """
        Gets the durable_medical_equipment of this Plan.
        Benefits summary for durable medical equipment

        :return: The durable_medical_equipment of this Plan.
        :rtype: str
        """
        return self._durable_medical_equipment

    @durable_medical_equipment.setter
    def durable_medical_equipment(self, durable_medical_equipment):
        """
        Sets the durable_medical_equipment of this Plan.
        Benefits summary for durable medical equipment

        :param durable_medical_equipment: The durable_medical_equipment of this Plan.
        :type: str
        """

        self._durable_medical_equipment = durable_medical_equipment

    @property
    def diagnostic_test(self):
        """
        Gets the diagnostic_test of this Plan.
        Diagnostic tests benefit summary

        :return: The diagnostic_test of this Plan.
        :rtype: str
        """
        return self._diagnostic_test

    @diagnostic_test.setter
    def diagnostic_test(self, diagnostic_test):
        """
        Sets the diagnostic_test of this Plan.
        Diagnostic tests benefit summary

        :param diagnostic_test: The diagnostic_test of this Plan.
        :type: str
        """

        self._diagnostic_test = diagnostic_test

    @property
    def display_name(self):
        """
        Gets the display_name of this Plan.
        Alternate name for the Plan

        :return: The display_name of this Plan.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Plan.
        Alternate name for the Plan

        :param display_name: The display_name of this Plan.
        :type: str
        """

        self._display_name = display_name

    @property
    def dp_rider(self):
        """
        Gets the dp_rider of this Plan.
        Is this a domestic plan?

        :return: The dp_rider of this Plan.
        :rtype: bool
        """
        return self._dp_rider

    @dp_rider.setter
    def dp_rider(self, dp_rider):
        """
        Sets the dp_rider of this Plan.
        Is this a domestic plan?

        :param dp_rider: The dp_rider of this Plan.
        :type: bool
        """

        self._dp_rider = dp_rider

    @property
    def drug_formulary_url(self):
        """
        Gets the drug_formulary_url of this Plan.
        Link to the summary of drug benefits for the plan

        :return: The drug_formulary_url of this Plan.
        :rtype: str
        """
        return self._drug_formulary_url

    @drug_formulary_url.setter
    def drug_formulary_url(self, drug_formulary_url):
        """
        Sets the drug_formulary_url of this Plan.
        Link to the summary of drug benefits for the plan

        :param drug_formulary_url: The drug_formulary_url of this Plan.
        :type: str
        """

        self._drug_formulary_url = drug_formulary_url

    @property
    def effective_date(self):
        """
        Gets the effective_date of this Plan.
        Effective date of coverage.

        :return: The effective_date of this Plan.
        :rtype: str
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """
        Sets the effective_date of this Plan.
        Effective date of coverage.

        :param effective_date: The effective_date of this Plan.
        :type: str
        """

        self._effective_date = effective_date

    @property
    def expiration_date(self):
        """
        Gets the expiration_date of this Plan.
        Expiration date of coverage.

        :return: The expiration_date of this Plan.
        :rtype: str
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """
        Sets the expiration_date of this Plan.
        Expiration date of coverage.

        :param expiration_date: The expiration_date of this Plan.
        :type: str
        """

        self._expiration_date = expiration_date

    @property
    def emergency_room(self):
        """
        Gets the emergency_room of this Plan.
        Description of costs when visiting the ER

        :return: The emergency_room of this Plan.
        :rtype: str
        """
        return self._emergency_room

    @emergency_room.setter
    def emergency_room(self, emergency_room):
        """
        Sets the emergency_room of this Plan.
        Description of costs when visiting the ER

        :param emergency_room: The emergency_room of this Plan.
        :type: str
        """

        self._emergency_room = emergency_room

    @property
    def family_drug_deductible(self):
        """
        Gets the family_drug_deductible of this Plan.
        Deductible for drugs when a family is on the plan.

        :return: The family_drug_deductible of this Plan.
        :rtype: str
        """
        return self._family_drug_deductible

    @family_drug_deductible.setter
    def family_drug_deductible(self, family_drug_deductible):
        """
        Sets the family_drug_deductible of this Plan.
        Deductible for drugs when a family is on the plan.

        :param family_drug_deductible: The family_drug_deductible of this Plan.
        :type: str
        """

        self._family_drug_deductible = family_drug_deductible

    @property
    def family_drug_moop(self):
        """
        Gets the family_drug_moop of this Plan.
        Maximum out-of-pocket for drugs when a family is on the plan

        :return: The family_drug_moop of this Plan.
        :rtype: str
        """
        return self._family_drug_moop

    @family_drug_moop.setter
    def family_drug_moop(self, family_drug_moop):
        """
        Sets the family_drug_moop of this Plan.
        Maximum out-of-pocket for drugs when a family is on the plan

        :param family_drug_moop: The family_drug_moop of this Plan.
        :type: str
        """

        self._family_drug_moop = family_drug_moop

    @property
    def family_medical_deductible(self):
        """
        Gets the family_medical_deductible of this Plan.
        Deductible when a family is on the plan

        :return: The family_medical_deductible of this Plan.
        :rtype: str
        """
        return self._family_medical_deductible

    @family_medical_deductible.setter
    def family_medical_deductible(self, family_medical_deductible):
        """
        Sets the family_medical_deductible of this Plan.
        Deductible when a family is on the plan

        :param family_medical_deductible: The family_medical_deductible of this Plan.
        :type: str
        """

        self._family_medical_deductible = family_medical_deductible

    @property
    def family_medical_moop(self):
        """
        Gets the family_medical_moop of this Plan.
        Maximum out-of-pocket when a family is on the plan

        :return: The family_medical_moop of this Plan.
        :rtype: str
        """
        return self._family_medical_moop

    @family_medical_moop.setter
    def family_medical_moop(self, family_medical_moop):
        """
        Sets the family_medical_moop of this Plan.
        Maximum out-of-pocket when a family is on the plan

        :param family_medical_moop: The family_medical_moop of this Plan.
        :type: str
        """

        self._family_medical_moop = family_medical_moop

    @property
    def fp_rider(self):
        """
        Gets the fp_rider of this Plan.
        Is this a family plan?

        :return: The fp_rider of this Plan.
        :rtype: bool
        """
        return self._fp_rider

    @fp_rider.setter
    def fp_rider(self, fp_rider):
        """
        Sets the fp_rider of this Plan.
        Is this a family plan?

        :param fp_rider: The fp_rider of this Plan.
        :type: bool
        """

        self._fp_rider = fp_rider

    @property
    def generic_drugs(self):
        """
        Gets the generic_drugs of this Plan.
        Cost for generic drugs

        :return: The generic_drugs of this Plan.
        :rtype: str
        """
        return self._generic_drugs

    @generic_drugs.setter
    def generic_drugs(self, generic_drugs):
        """
        Sets the generic_drugs of this Plan.
        Cost for generic drugs

        :param generic_drugs: The generic_drugs of this Plan.
        :type: str
        """

        self._generic_drugs = generic_drugs

    @property
    def habilitation_services(self):
        """
        Gets the habilitation_services of this Plan.
        Habilitation services benefits summary

        :return: The habilitation_services of this Plan.
        :rtype: str
        """
        return self._habilitation_services

    @habilitation_services.setter
    def habilitation_services(self, habilitation_services):
        """
        Sets the habilitation_services of this Plan.
        Habilitation services benefits summary

        :param habilitation_services: The habilitation_services of this Plan.
        :type: str
        """

        self._habilitation_services = habilitation_services

    @property
    def hios_issuer_id(self):
        """
        Gets the hios_issuer_id of this Plan.
        

        :return: The hios_issuer_id of this Plan.
        :rtype: str
        """
        return self._hios_issuer_id

    @hios_issuer_id.setter
    def hios_issuer_id(self, hios_issuer_id):
        """
        Sets the hios_issuer_id of this Plan.
        

        :param hios_issuer_id: The hios_issuer_id of this Plan.
        :type: str
        """

        self._hios_issuer_id = hios_issuer_id

    @property
    def home_health_care(self):
        """
        Gets the home_health_care of this Plan.
        Home health care benefits summary

        :return: The home_health_care of this Plan.
        :rtype: str
        """
        return self._home_health_care

    @home_health_care.setter
    def home_health_care(self, home_health_care):
        """
        Sets the home_health_care of this Plan.
        Home health care benefits summary

        :param home_health_care: The home_health_care of this Plan.
        :type: str
        """

        self._home_health_care = home_health_care

    @property
    def hospice_service(self):
        """
        Gets the hospice_service of this Plan.
        Hospice service benefits summary

        :return: The hospice_service of this Plan.
        :rtype: str
        """
        return self._hospice_service

    @hospice_service.setter
    def hospice_service(self, hospice_service):
        """
        Sets the hospice_service of this Plan.
        Hospice service benefits summary

        :param hospice_service: The hospice_service of this Plan.
        :type: str
        """

        self._hospice_service = hospice_service

    @property
    def hsa_eligible(self):
        """
        Gets the hsa_eligible of this Plan.
        Is the plan HSA eligible?

        :return: The hsa_eligible of this Plan.
        :rtype: bool
        """
        return self._hsa_eligible

    @hsa_eligible.setter
    def hsa_eligible(self, hsa_eligible):
        """
        Sets the hsa_eligible of this Plan.
        Is the plan HSA eligible?

        :param hsa_eligible: The hsa_eligible of this Plan.
        :type: bool
        """

        self._hsa_eligible = hsa_eligible

    @property
    def id(self):
        """
        Gets the id of this Plan.
        Government-issued HIOS plan ID

        :return: The id of this Plan.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Plan.
        Government-issued HIOS plan ID

        :param id: The id of this Plan.
        :type: str
        """

        self._id = id

    @property
    def imaging(self):
        """
        Gets the imaging of this Plan.
        Benefits summary for imaging coverage

        :return: The imaging of this Plan.
        :rtype: str
        """
        return self._imaging

    @imaging.setter
    def imaging(self, imaging):
        """
        Sets the imaging of this Plan.
        Benefits summary for imaging coverage

        :param imaging: The imaging of this Plan.
        :type: str
        """

        self._imaging = imaging

    @property
    def in_network_ids(self):
        """
        Gets the in_network_ids of this Plan.
        List of NPI numbers for Providers passed in who accept this Plan

        :return: The in_network_ids of this Plan.
        :rtype: list[int]
        """
        return self._in_network_ids

    @in_network_ids.setter
    def in_network_ids(self, in_network_ids):
        """
        Sets the in_network_ids of this Plan.
        List of NPI numbers for Providers passed in who accept this Plan

        :param in_network_ids: The in_network_ids of this Plan.
        :type: list[int]
        """

        self._in_network_ids = in_network_ids

    @property
    def individual_drug_deductible(self):
        """
        Gets the individual_drug_deductible of this Plan.
        Deductible for drugs when an individual is on the plan

        :return: The individual_drug_deductible of this Plan.
        :rtype: str
        """
        return self._individual_drug_deductible

    @individual_drug_deductible.setter
    def individual_drug_deductible(self, individual_drug_deductible):
        """
        Sets the individual_drug_deductible of this Plan.
        Deductible for drugs when an individual is on the plan

        :param individual_drug_deductible: The individual_drug_deductible of this Plan.
        :type: str
        """

        self._individual_drug_deductible = individual_drug_deductible

    @property
    def individual_drug_moop(self):
        """
        Gets the individual_drug_moop of this Plan.
        Maximum out-of-pocket for drugs when an individual is on the plan

        :return: The individual_drug_moop of this Plan.
        :rtype: str
        """
        return self._individual_drug_moop

    @individual_drug_moop.setter
    def individual_drug_moop(self, individual_drug_moop):
        """
        Sets the individual_drug_moop of this Plan.
        Maximum out-of-pocket for drugs when an individual is on the plan

        :param individual_drug_moop: The individual_drug_moop of this Plan.
        :type: str
        """

        self._individual_drug_moop = individual_drug_moop

    @property
    def individual_medical_deductible(self):
        """
        Gets the individual_medical_deductible of this Plan.
        Deductible when an individual is on the plan

        :return: The individual_medical_deductible of this Plan.
        :rtype: str
        """
        return self._individual_medical_deductible

    @individual_medical_deductible.setter
    def individual_medical_deductible(self, individual_medical_deductible):
        """
        Sets the individual_medical_deductible of this Plan.
        Deductible when an individual is on the plan

        :param individual_medical_deductible: The individual_medical_deductible of this Plan.
        :type: str
        """

        self._individual_medical_deductible = individual_medical_deductible

    @property
    def individual_medical_moop(self):
        """
        Gets the individual_medical_moop of this Plan.
        Maximum out-of-pocket when an individual is on the plan

        :return: The individual_medical_moop of this Plan.
        :rtype: str
        """
        return self._individual_medical_moop

    @individual_medical_moop.setter
    def individual_medical_moop(self, individual_medical_moop):
        """
        Sets the individual_medical_moop of this Plan.
        Maximum out-of-pocket when an individual is on the plan

        :param individual_medical_moop: The individual_medical_moop of this Plan.
        :type: str
        """

        self._individual_medical_moop = individual_medical_moop

    @property
    def inpatient_birth(self):
        """
        Gets the inpatient_birth of this Plan.
        Inpatient birth benefits summary

        :return: The inpatient_birth of this Plan.
        :rtype: str
        """
        return self._inpatient_birth

    @inpatient_birth.setter
    def inpatient_birth(self, inpatient_birth):
        """
        Sets the inpatient_birth of this Plan.
        Inpatient birth benefits summary

        :param inpatient_birth: The inpatient_birth of this Plan.
        :type: str
        """

        self._inpatient_birth = inpatient_birth

    @property
    def inpatient_facility(self):
        """
        Gets the inpatient_facility of this Plan.
        Cost under the plan for an inpatient facility

        :return: The inpatient_facility of this Plan.
        :rtype: str
        """
        return self._inpatient_facility

    @inpatient_facility.setter
    def inpatient_facility(self, inpatient_facility):
        """
        Sets the inpatient_facility of this Plan.
        Cost under the plan for an inpatient facility

        :param inpatient_facility: The inpatient_facility of this Plan.
        :type: str
        """

        self._inpatient_facility = inpatient_facility

    @property
    def inpatient_mental_health(self):
        """
        Gets the inpatient_mental_health of this Plan.
        Inpatient mental helath benefits summary

        :return: The inpatient_mental_health of this Plan.
        :rtype: str
        """
        return self._inpatient_mental_health

    @inpatient_mental_health.setter
    def inpatient_mental_health(self, inpatient_mental_health):
        """
        Sets the inpatient_mental_health of this Plan.
        Inpatient mental helath benefits summary

        :param inpatient_mental_health: The inpatient_mental_health of this Plan.
        :type: str
        """

        self._inpatient_mental_health = inpatient_mental_health

    @property
    def inpatient_physician(self):
        """
        Gets the inpatient_physician of this Plan.
        Cost under the plan for an inpatient physician

        :return: The inpatient_physician of this Plan.
        :rtype: str
        """
        return self._inpatient_physician

    @inpatient_physician.setter
    def inpatient_physician(self, inpatient_physician):
        """
        Sets the inpatient_physician of this Plan.
        Cost under the plan for an inpatient physician

        :param inpatient_physician: The inpatient_physician of this Plan.
        :type: str
        """

        self._inpatient_physician = inpatient_physician

    @property
    def inpatient_substance(self):
        """
        Gets the inpatient_substance of this Plan.
        Inpatient substance abuse benefits summary

        :return: The inpatient_substance of this Plan.
        :rtype: str
        """
        return self._inpatient_substance

    @inpatient_substance.setter
    def inpatient_substance(self, inpatient_substance):
        """
        Sets the inpatient_substance of this Plan.
        Inpatient substance abuse benefits summary

        :param inpatient_substance: The inpatient_substance of this Plan.
        :type: str
        """

        self._inpatient_substance = inpatient_substance

    @property
    def level(self):
        """
        Gets the level of this Plan.
        Plan metal grouping (e.g. platinum, gold, silver, etc)

        :return: The level of this Plan.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this Plan.
        Plan metal grouping (e.g. platinum, gold, silver, etc)

        :param level: The level of this Plan.
        :type: str
        """

        self._level = level

    @property
    def logo_url(self):
        """
        Gets the logo_url of this Plan.
        Link to a copy of the insurance carrier's logo

        :return: The logo_url of this Plan.
        :rtype: str
        """
        return self._logo_url

    @logo_url.setter
    def logo_url(self, logo_url):
        """
        Sets the logo_url of this Plan.
        Link to a copy of the insurance carrier's logo

        :param logo_url: The logo_url of this Plan.
        :type: str
        """

        self._logo_url = logo_url

    @property
    def name(self):
        """
        Gets the name of this Plan.
        Marketing name of the plan

        :return: The name of this Plan.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Plan.
        Marketing name of the plan

        :param name: The name of this Plan.
        :type: str
        """

        self._name = name

    @property
    def network_size(self):
        """
        Gets the network_size of this Plan.
        Total number of Providers in network

        :return: The network_size of this Plan.
        :rtype: int
        """
        return self._network_size

    @network_size.setter
    def network_size(self, network_size):
        """
        Sets the network_size of this Plan.
        Total number of Providers in network

        :param network_size: The network_size of this Plan.
        :type: int
        """

        self._network_size = network_size

    @property
    def non_preferred_brand_drugs(self):
        """
        Gets the non_preferred_brand_drugs of this Plan.
        Cost under the plan for non-preferred brand drugs

        :return: The non_preferred_brand_drugs of this Plan.
        :rtype: str
        """
        return self._non_preferred_brand_drugs

    @non_preferred_brand_drugs.setter
    def non_preferred_brand_drugs(self, non_preferred_brand_drugs):
        """
        Sets the non_preferred_brand_drugs of this Plan.
        Cost under the plan for non-preferred brand drugs

        :param non_preferred_brand_drugs: The non_preferred_brand_drugs of this Plan.
        :type: str
        """

        self._non_preferred_brand_drugs = non_preferred_brand_drugs

    @property
    def on_market(self):
        """
        Gets the on_market of this Plan.
        Is the plan on-market?

        :return: The on_market of this Plan.
        :rtype: bool
        """
        return self._on_market

    @on_market.setter
    def on_market(self, on_market):
        """
        Sets the on_market of this Plan.
        Is the plan on-market?

        :param on_market: The on_market of this Plan.
        :type: bool
        """

        self._on_market = on_market

    @property
    def off_market(self):
        """
        Gets the off_market of this Plan.
        Is the plan off-market?

        :return: The off_market of this Plan.
        :rtype: bool
        """
        return self._off_market

    @off_market.setter
    def off_market(self, off_market):
        """
        Sets the off_market of this Plan.
        Is the plan off-market?

        :param off_market: The off_market of this Plan.
        :type: bool
        """

        self._off_market = off_market

    @property
    def out_of_network_coverage(self):
        """
        Gets the out_of_network_coverage of this Plan.
        Does this plan provide any out of network coverage?

        :return: The out_of_network_coverage of this Plan.
        :rtype: bool
        """
        return self._out_of_network_coverage

    @out_of_network_coverage.setter
    def out_of_network_coverage(self, out_of_network_coverage):
        """
        Sets the out_of_network_coverage of this Plan.
        Does this plan provide any out of network coverage?

        :param out_of_network_coverage: The out_of_network_coverage of this Plan.
        :type: bool
        """

        self._out_of_network_coverage = out_of_network_coverage

    @property
    def out_of_network_ids(self):
        """
        Gets the out_of_network_ids of this Plan.
        List of NPI numbers for Providers passed in who do not accept this Plan

        :return: The out_of_network_ids of this Plan.
        :rtype: list[int]
        """
        return self._out_of_network_ids

    @out_of_network_ids.setter
    def out_of_network_ids(self, out_of_network_ids):
        """
        Sets the out_of_network_ids of this Plan.
        List of NPI numbers for Providers passed in who do not accept this Plan

        :param out_of_network_ids: The out_of_network_ids of this Plan.
        :type: list[int]
        """

        self._out_of_network_ids = out_of_network_ids

    @property
    def outpatient_facility(self):
        """
        Gets the outpatient_facility of this Plan.
        Benefits summary for outpatient facility coverage

        :return: The outpatient_facility of this Plan.
        :rtype: str
        """
        return self._outpatient_facility

    @outpatient_facility.setter
    def outpatient_facility(self, outpatient_facility):
        """
        Sets the outpatient_facility of this Plan.
        Benefits summary for outpatient facility coverage

        :param outpatient_facility: The outpatient_facility of this Plan.
        :type: str
        """

        self._outpatient_facility = outpatient_facility

    @property
    def outpatient_mental_health(self):
        """
        Gets the outpatient_mental_health of this Plan.
        Benefits summary for outpatient mental health coverage

        :return: The outpatient_mental_health of this Plan.
        :rtype: str
        """
        return self._outpatient_mental_health

    @outpatient_mental_health.setter
    def outpatient_mental_health(self, outpatient_mental_health):
        """
        Sets the outpatient_mental_health of this Plan.
        Benefits summary for outpatient mental health coverage

        :param outpatient_mental_health: The outpatient_mental_health of this Plan.
        :type: str
        """

        self._outpatient_mental_health = outpatient_mental_health

    @property
    def outpatient_physician(self):
        """
        Gets the outpatient_physician of this Plan.
        Benefits summary for outpatient physician coverage

        :return: The outpatient_physician of this Plan.
        :rtype: str
        """
        return self._outpatient_physician

    @outpatient_physician.setter
    def outpatient_physician(self, outpatient_physician):
        """
        Sets the outpatient_physician of this Plan.
        Benefits summary for outpatient physician coverage

        :param outpatient_physician: The outpatient_physician of this Plan.
        :type: str
        """

        self._outpatient_physician = outpatient_physician

    @property
    def outpatient_substance(self):
        """
        Gets the outpatient_substance of this Plan.
        Outpatient substance abuse benefits summary

        :return: The outpatient_substance of this Plan.
        :rtype: str
        """
        return self._outpatient_substance

    @outpatient_substance.setter
    def outpatient_substance(self, outpatient_substance):
        """
        Sets the outpatient_substance of this Plan.
        Outpatient substance abuse benefits summary

        :param outpatient_substance: The outpatient_substance of this Plan.
        :type: str
        """

        self._outpatient_substance = outpatient_substance

    @property
    def plan_market(self):
        """
        Gets the plan_market of this Plan.
        Market in which the plan is offered (on_marketplace, shop, etc)

        :return: The plan_market of this Plan.
        :rtype: str
        """
        return self._plan_market

    @plan_market.setter
    def plan_market(self, plan_market):
        """
        Sets the plan_market of this Plan.
        Market in which the plan is offered (on_marketplace, shop, etc)

        :param plan_market: The plan_market of this Plan.
        :type: str
        """

        self._plan_market = plan_market

    @property
    def plan_type(self):
        """
        Gets the plan_type of this Plan.
        Category of the plan (e.g. EPO, HMO, PPO, POS, Indemnity)

        :return: The plan_type of this Plan.
        :rtype: str
        """
        return self._plan_type

    @plan_type.setter
    def plan_type(self, plan_type):
        """
        Sets the plan_type of this Plan.
        Category of the plan (e.g. EPO, HMO, PPO, POS, Indemnity)

        :param plan_type: The plan_type of this Plan.
        :type: str
        """

        self._plan_type = plan_type

    @property
    def preferred_brand_drugs(self):
        """
        Gets the preferred_brand_drugs of this Plan.
        Cost under the plan for perferred brand drugs

        :return: The preferred_brand_drugs of this Plan.
        :rtype: str
        """
        return self._preferred_brand_drugs

    @preferred_brand_drugs.setter
    def preferred_brand_drugs(self, preferred_brand_drugs):
        """
        Sets the preferred_brand_drugs of this Plan.
        Cost under the plan for perferred brand drugs

        :param preferred_brand_drugs: The preferred_brand_drugs of this Plan.
        :type: str
        """

        self._preferred_brand_drugs = preferred_brand_drugs

    @property
    def prenatal_postnatal_care(self):
        """
        Gets the prenatal_postnatal_care of this Plan.
        Inpatient substance abuse benefits summary

        :return: The prenatal_postnatal_care of this Plan.
        :rtype: str
        """
        return self._prenatal_postnatal_care

    @prenatal_postnatal_care.setter
    def prenatal_postnatal_care(self, prenatal_postnatal_care):
        """
        Sets the prenatal_postnatal_care of this Plan.
        Inpatient substance abuse benefits summary

        :param prenatal_postnatal_care: The prenatal_postnatal_care of this Plan.
        :type: str
        """

        self._prenatal_postnatal_care = prenatal_postnatal_care

    @property
    def preventative_care(self):
        """
        Gets the preventative_care of this Plan.
        Benefits summary for preventative care

        :return: The preventative_care of this Plan.
        :rtype: str
        """
        return self._preventative_care

    @preventative_care.setter
    def preventative_care(self, preventative_care):
        """
        Sets the preventative_care of this Plan.
        Benefits summary for preventative care

        :param preventative_care: The preventative_care of this Plan.
        :type: str
        """

        self._preventative_care = preventative_care

    @property
    def premium_subsidized(self):
        """
        Gets the premium_subsidized of this Plan.
        Cumulative premium amount after subsidy

        :return: The premium_subsidized of this Plan.
        :rtype: float
        """
        return self._premium_subsidized

    @premium_subsidized.setter
    def premium_subsidized(self, premium_subsidized):
        """
        Sets the premium_subsidized of this Plan.
        Cumulative premium amount after subsidy

        :param premium_subsidized: The premium_subsidized of this Plan.
        :type: float
        """

        self._premium_subsidized = premium_subsidized

    @property
    def premium(self):
        """
        Gets the premium of this Plan.
        Cumulative premium amount

        :return: The premium of this Plan.
        :rtype: float
        """
        return self._premium

    @premium.setter
    def premium(self, premium):
        """
        Sets the premium of this Plan.
        Cumulative premium amount

        :param premium: The premium of this Plan.
        :type: float
        """

        self._premium = premium

    @property
    def primary_care_physician(self):
        """
        Gets the primary_care_physician of this Plan.
        Cost under the plan to visit a Primary Care Physician

        :return: The primary_care_physician of this Plan.
        :rtype: str
        """
        return self._primary_care_physician

    @primary_care_physician.setter
    def primary_care_physician(self, primary_care_physician):
        """
        Sets the primary_care_physician of this Plan.
        Cost under the plan to visit a Primary Care Physician

        :param primary_care_physician: The primary_care_physician of this Plan.
        :type: str
        """

        self._primary_care_physician = primary_care_physician

    @property
    def rehabilitation_services(self):
        """
        Gets the rehabilitation_services of this Plan.
        Benefits summary for rehabilitation services

        :return: The rehabilitation_services of this Plan.
        :rtype: str
        """
        return self._rehabilitation_services

    @rehabilitation_services.setter
    def rehabilitation_services(self, rehabilitation_services):
        """
        Sets the rehabilitation_services of this Plan.
        Benefits summary for rehabilitation services

        :param rehabilitation_services: The rehabilitation_services of this Plan.
        :type: str
        """

        self._rehabilitation_services = rehabilitation_services

    @property
    def service_area_id(self):
        """
        Gets the service_area_id of this Plan.
        Foreign key for service area

        :return: The service_area_id of this Plan.
        :rtype: str
        """
        return self._service_area_id

    @service_area_id.setter
    def service_area_id(self, service_area_id):
        """
        Sets the service_area_id of this Plan.
        Foreign key for service area

        :param service_area_id: The service_area_id of this Plan.
        :type: str
        """

        self._service_area_id = service_area_id

    @property
    def skilled_nursing(self):
        """
        Gets the skilled_nursing of this Plan.
        Benefits summary for skilled nursing services

        :return: The skilled_nursing of this Plan.
        :rtype: str
        """
        return self._skilled_nursing

    @skilled_nursing.setter
    def skilled_nursing(self, skilled_nursing):
        """
        Sets the skilled_nursing of this Plan.
        Benefits summary for skilled nursing services

        :param skilled_nursing: The skilled_nursing of this Plan.
        :type: str
        """

        self._skilled_nursing = skilled_nursing

    @property
    def specialist(self):
        """
        Gets the specialist of this Plan.
        Cost under the plan to visit a specialist

        :return: The specialist of this Plan.
        :rtype: str
        """
        return self._specialist

    @specialist.setter
    def specialist(self, specialist):
        """
        Sets the specialist of this Plan.
        Cost under the plan to visit a specialist

        :param specialist: The specialist of this Plan.
        :type: str
        """

        self._specialist = specialist

    @property
    def specialty_drugs(self):
        """
        Gets the specialty_drugs of this Plan.
        Cost under the plan for specialty drugs

        :return: The specialty_drugs of this Plan.
        :rtype: str
        """
        return self._specialty_drugs

    @specialty_drugs.setter
    def specialty_drugs(self, specialty_drugs):
        """
        Sets the specialty_drugs of this Plan.
        Cost under the plan for specialty drugs

        :param specialty_drugs: The specialty_drugs of this Plan.
        :type: str
        """

        self._specialty_drugs = specialty_drugs

    @property
    def urgent_care(self):
        """
        Gets the urgent_care of this Plan.
        Benefits summary for urgent care

        :return: The urgent_care of this Plan.
        :rtype: str
        """
        return self._urgent_care

    @urgent_care.setter
    def urgent_care(self, urgent_care):
        """
        Sets the urgent_care of this Plan.
        Benefits summary for urgent care

        :param urgent_care: The urgent_care of this Plan.
        :type: str
        """

        self._urgent_care = urgent_care

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
